#!/bin/csh

#
# Processing of a 2D Plane from 3D States HN-Detected data:
#   "POLY -time" subtracts solvent by polynomial fitting.
#   "EXT -left" extracts left half of HN dimension.

# This script combines standard processing with the pseudo-3D
# commands original found in setT2series.com

set tauValues = (20 210 1 160 100 190 50 290)
set idxExpmt  = (2 7 1 5 4 6 3 8)

rm -rf ft
mkdir ft

foreach n ( `seq 1 ${#tauValues}` )
  echo Time t${n} \($tauValues[$n] ms\)...
  set outName = (`printf ft/test%03d.ft2 $idxExpmt[$n]`)
  set inName  = (`printf fid/test%03d.fid $n`)
  echo "* input  = $inName"
  echo "* output = $outName"

  nmrPipe -in $inName \
  | nmrPipe  -fn POLY -time                            \
  | nmrPipe  -fn SP -off 0.5 -end 0.98 -pow 2 -c 0.5    \
  | nmrPipe  -fn ZF -size 4096                          \
  | nmrPipe  -fn FT                                     \
  | nmrPipe  -fn EXT -x1 11ppm -xn 6ppm -sw -verb       \
  | nmrPipe  -fn PS -p0 12.5 -p1 0 -di                     \
  | nmrPipe  -fn TP                                     \
  | nmrPipe  -fn SP -off 0.5 -end 0.98 -pow 1 -c 0.5    \
  | nmrPipe  -fn ZF -size 512                           \
  | nmrPipe  -fn FT                                     \
  | nmrPipe  -fn PS -p0 -90 -p1 0 -di                 \
  | nmrPipe  -fn TP                                     \
  | nmrPipe  -fn POLY -auto -ord 2                      \
     -verb -ov -out $outName

  #@ i = $n - 1
  sethdr $outName -tau $tauValues[$n]
end

series.com ft/test*.ft2
